summaryrefslogtreecommitdiff
path: root/ace/Strategies_T.h
diff options
context:
space:
mode:
authorschmidt <douglascraigschmidt@users.noreply.github.com>1999-02-01 01:25:06 +0000
committerschmidt <douglascraigschmidt@users.noreply.github.com>1999-02-01 01:25:06 +0000
commitcecf8ae614b687b165257de7246d75b823593d00 (patch)
tree68000c06cee8e67c7d3ed2377fbb8866b2dfec97 /ace/Strategies_T.h
parent3f86474fbd339a45d6614526870b11b7fd0f6920 (diff)
downloadATCD-cecf8ae614b687b165257de7246d75b823593d00.tar.gz
.
Diffstat (limited to 'ace/Strategies_T.h')
-rw-r--r--ace/Strategies_T.h21
1 files changed, 9 insertions, 12 deletions
diff --git a/ace/Strategies_T.h b/ace/Strategies_T.h
index 397945cd7bb..d8703ce1b47 100644
--- a/ace/Strategies_T.h
+++ b/ace/Strategies_T.h
@@ -348,28 +348,25 @@ class ACE_Process_Strategy : public ACE_Concurrency_Strategy<SVC_HANDLER>
// = DESCRIPTION
// This class provides a strategy that manages the creation of
// processes to handle requests from clients concurrently. It
- // behaves as a "process factory", using <ACE_OS::fork> or
- // <ACE::daemonize> to fork threads "on-demand" to run the
- // service specified by a user-supplied <SVC_HANDLER> in a
- // separate process.
+ // behaves as a "process factory", using <ACE::fork> to fork
+ // threads "on-demand" to run the service specified by a
+ // user-supplied <SVC_HANDLER> in a separate process.
public:
// = Intialization and termination methods.
ACE_Process_Strategy (size_t n_processes = 1,
ACE_Event_Handler *acceptor = 0,
ACE_Reactor * = 0,
- int daemonize = 0);
- // Initialize the strategy. If <daemonize> is non-0 then use the
- // <ACE::daemonize> method instead of <ACE_OS::fork> to avoid
- // zombies.
+ int avoid_zombies = 0);
+ // Initialize the strategy. If <avoid_zombies> is non-0 then set a
+ // flag to <ACE::fork> to avoid zombies.
virtual int open (size_t n_processes = 1,
ACE_Event_Handler *acceptor = 0,
ACE_Reactor * = 0,
- int daemonize = 0);
- // Initialize the strategy. If <daemonize> is non-0 then use the
- // <ACE::daemonize> method instead of <ACE_OS::fork> to avoid
- // zombies.
+ int avoid_zombies = 0);
+ // Initialize the strategy. If <avoid_zombies> is non-0 then set a
+ // flag to <ACE::fork> to avoid zombies.
virtual ~ACE_Process_Strategy (void);